@@ -1,5 +1,6 @@
 package HTML::FormFu;
 use Moose;
+use MooseX::Attribute::Chained;
 
 with 'HTML::FormFu::Role::Render',
      'HTML::FormFu::Role::CreateChildren',
@@ -28,6 +29,7 @@ use HTML::FormFu::ObjectUtil qw(
     load_config_file            load_config_filestem
     clone                       stash
     constraints_from_dbic       parent
+    _load_file
 );
 use HTML::FormFu::Util qw(
     DEBUG
@@ -141,7 +143,7 @@ __PACKAGE__->mk_inherited_merging_accessors(qw( tt_args config_callback ));
 *plugins           = \&plugin;
 *add_plugins       = \&add_plugin;
 
-our $VERSION = '0.09005';
+our $VERSION = '0.09006';
 $VERSION = eval $VERSION;
 
 sub BUILD {
@@ -3189,6 +3191,8 @@ Moritz Onken
 
 Doug Orleans
 
+Matthias Dietrich
+
 Based on the original source code of L<HTML::Widget>, by Sebastian Riedel,
 C<sri@oook.de>.
 
