@@ -1,12 +1,14 @@
 package HTML::FormFu::Constraint::Bool;
 
-use strict;
-use base 'HTML::FormFu::Constraint::Regex';
+use Moose;
+extends 'HTML::FormFu::Constraint::Regex';
 
 sub regex {
     return qr/^[01]?\z/;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -34,3 +36,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
