@@ -1,11 +1,13 @@
 package HTML::FormFu::Element::ComboBox;
-use strict;
-use base 'HTML::FormFu::Element::Multi';
-use Class::C3;
+use Moose;
+use MooseX::Attribute::Chained;
+extends 'HTML::FormFu::Element::Multi';
+
+with 'HTML::FormFu::Role::Element::ProcessOptionsFromModel';
 
-use HTML::FormFu::Element::_Group qw( _process_options_from_model );
 use HTML::FormFu::Util qw( _filter_components _parse_args );
 use List::MoreUtils qw( any );
+use Moose::Util qw( apply_all_roles );
 
 our @DEFER_TO_SELECT = qw(
     empty_first
@@ -14,12 +16,12 @@ our @DEFER_TO_SELECT = qw(
     value_range
 );
 
-__PACKAGE__->mk_accessors(
-    @DEFER_TO_SELECT,
-    qw(
-        select
-        text
-        ) );
+for my $name ( @DEFER_TO_SELECT ) {
+    has $name => ( is => 'rw', traits  => ['Chained'] );
+}
+
+has select => ( is => 'rw', traits  => ['Chained'], default => sub { {} } );
+has text   => ( is => 'rw', traits  => ['Chained'], default => sub { {} } );
 
 *default = \&value;
 
@@ -49,18 +51,14 @@ for my $method ( qw(
     *{$name} = $sub;
 }
 
-sub new {
-    my $self = shift->next::method(@_);
-
-    $self->multi_value(1);
-    $self->empty_first(1);
-
-    $self->select( { type => '_MultiSelect', } );
-
-    $self->text( { type => '_MultiText', } );
-
-    return $self;
-}
+after BUILD => sub {
+    my ( $self, $args ) = @_;
+    
+    $self->multi_value( 1 );
+    $self->empty_first( 1 );
+    
+    return;
+};
 
 sub options {
     my ( $self, @args ) = @_;
@@ -124,6 +122,13 @@ sub _combobox_defaults {
     my ($self) = @_;
 
     if ( defined( my $default = $self->default ) ) {
+        
+        if ( !$self->form->submitted || $self->render_processed_value ) {
+            for my $deflator ( @{ $self->_deflators } ) {
+                $default = $deflator->process($default);
+            }
+        }
+        
         my $select_options = $self->_elements->[0]->options;
 
         if ( $default ne ''
@@ -149,10 +154,12 @@ sub _add_select {
     my $select_name = _build_field_name( $self, 'select' );
 
     my $select_element = $self->element( {
-            type => $select->{type},
+            type => 'Select',
             name => $select_name,
         } );
 
+    apply_all_roles( $select_element, 'HTML::FormFu::Role::Element::MultiElement' );
+
     for my $method (@DEFER_TO_SELECT) {
         if ( defined( my $value = $self->$method ) ) {
             $select_element->$method($value);
@@ -181,10 +188,12 @@ sub _add_text {
     my $text_name = _build_field_name( $self, 'text' );
 
     my $text_element = $self->element( {
-            type => $text->{type},
+            type => 'Text',
             name => $text_name,
         } );
 
+    apply_all_roles( $text_element, 'HTML::FormFu::Role::Element::MultiElement' );
+
     if ( defined( my $default = $text->{default} ) ) {
         $text_element->default($default);
     }
@@ -215,7 +224,7 @@ sub process {
 
     $self->_add_elements;
 
-    return $self->next::method(@args);
+    return $self->SUPER::process(@args);
 }
 
 sub process_input {
@@ -239,7 +248,7 @@ sub process_input {
         );
     }
 
-    return $self->next::method($input);
+    return $self->SUPER::process_input($input);
 }
 
 sub render_data {
@@ -249,7 +258,7 @@ sub render_data {
 sub render_data_non_recursive {
     my ( $self, $args ) = @_;
 
-    my $render = $self->next::method( {
+    my $render = $self->SUPER::render_data_non_recursive( {
             elements => [ map { $_->render_data } @{ $self->_elements } ],
             $args ? %$args : (),
         } );
@@ -257,6 +266,8 @@ sub render_data_non_recursive {
     return $render;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -314,11 +325,11 @@ See L<HTML::FormFu::Element::_Group/value_range> for details.
 
 =head2 empty_first
 
-See L<HTML::FormFu::Element::Select/empty_first> for details.
+See L<HTML::FormFu::Element::_Group/empty_first> for details.
 
 =head2 empty_first_label
 
-See L<HTML::FormFu::Element::Select/empty_first_label> for details.
+See L<HTML::FormFu::Element::_Group/empty_first_label> for details.
 
 =head2 select
 
@@ -355,8 +366,8 @@ added directly to the date element, not to its child elements.
 This element's L<get_elements|HTML::FormFu/get_elements> and 
 L<get_all_elements|HTML::FormFu/get_all_elements> are inherited from 
 L<HTML::FormFu::Element::Block>, and so have the same behaviour. However, it 
-overrides the C<get_fields> method, such that it returns both itself and 
-its child elements.
+overrides the C<get_fields|HTML::FormFu/get_fields> method, such that it
+returns both itself and its child elements.
 
 =head1 SEE ALSO
 
@@ -375,3 +386,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
