@@ -1,16 +1,17 @@
 package HTML::FormFu::Element::Src;
 
-use strict;
-use base 'HTML::FormFu::Element::Block';
-use Class::C3;
+use Moose;
+extends 'HTML::FormFu::Element::Block';
 
-sub new {
-    my $self = shift->next::method(@_);
+after BUILD => sub {
+    my $self = shift;
 
     $self->tag(undef);
 
-    return $self;
-}
+    return;
+};
+
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -18,7 +19,7 @@ __END__
 
 =head1 NAME
 
-HTML::FormFu::Element::Src
+HTML::FormFu::Element::Src - custom HTML element
 
 =head1 DESCRIPTION
 
@@ -31,7 +32,7 @@ Is a sub-class of, and inherits methods from
 L<HTML::FormFu::Element::Block>, 
 L<HTML::FormFu::Element>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
@@ -41,3 +42,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
