@@ -1,11 +1,13 @@
 package HTML::FormFu::Filter::CompoundJoin;
+use Moose;
+use MooseX::Attribute::Chained;
+extends 'HTML::FormFu::Filter';
 
-use strict;
-use base 'HTML::FormFu::Filter::_Compound';
+with 'HTML::FormFu::Role::Filter::Compound';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR $SPACE );
 
-__PACKAGE__->mk_item_accessors(qw( join ));
+has join => ( is => 'rw', traits => ['Chained'] );
 
 sub filter {
     my ( $self, $value ) = @_;
@@ -26,6 +28,8 @@ sub filter {
     return $value;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
