@@ -1,9 +1,10 @@
 package HTML::FormFu::Filter::CopyValue;
 
-use strict;
-use base 'HTML::FormFu::Filter';
+use Moose;
+use MooseX::Attribute::Chained;
+extends 'HTML::FormFu::Filter';
 
-__PACKAGE__->mk_item_accessors(qw( field ));
+has field => ( is => 'rw', traits => ['Chained'] );
 
 sub filter {
     my ( $self, $value ) = @_;
@@ -22,13 +23,15 @@ sub filter {
     return $field_value;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
 =head1 NAME
 
-HTML::FormFu::Filter::CopyValue - copy the value from an other field
+HTML::FormFu::Filter::CopyValue - copy the value from another field
 
 =head1 SYNOPSIS
 
@@ -48,12 +51,10 @@ is empty.
 
 =head1 CAVEATS
 
-If the value of the original field contains an invalid value (a value that
-will be constrained through a constraint) this invalid value will be choosen
-for this field (the field with CopyValue filter).
-
-So the user has to change two fields or you remove the invalid value in a
-custom constraint.
+If the original field contains an invalid value (a value that will be
+constrained through a constraint) that invalid value will be copied to this
+field (the field with the CopyValue filter).  So, the user has to change two
+fields, or you can remove the invalid value in a custom constraint.
 
 =head1 AUTHOR
 
