@@ -1,8 +1,8 @@
 package HTML::FormFu::I18N::ua;
-use strict;
 use utf8;
 
-use base qw( HTML::FormFu::I18N );
+use Moose;
+extends 'HTML::FormFu::I18N';
 
 our %Lexicon = (
     form_error_message =>
@@ -64,4 +64,6 @@ our %Lexicon = (
         'Помилка обробки файлу зображення',
 );
 
+__PACKAGE__->meta->make_immutable( inline_constructor => 0 );
+
 1;
